@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -38,7 +38,7 @@ class Israel(ObservedHolidayBase, HebrewCalendarHolidays):
     country = "IL"
     default_language = "he"
     # %s (observed).
-    observed_label = tr("(נצפה) %s")
+    observed_label = tr("%s (נצפה)")
     supported_categories = (OPTIONAL, PUBLIC, SCHOOL)
     supported_languages = ("en_US", "he", "th", "uk")
     weekend = {FRI, SAT}
