@@ -609,33 +609,7 @@ class MalaysiaBuddhistHolidays(_CustomBuddhistHolidays):
 
 
 class MalaysiaChineseHolidays(_CustomChineseHolidays):
-    LUNAR_NEW_YEAR_DATES = {
-        2001: (JAN, 24),
-        2002: (FEB, 12),
-        2003: (FEB, 1),
-        2004: (JAN, 22),
-        2005: (FEB, 9),
-        2006: (JAN, 29),
-        2007: (FEB, 18),
-        2008: (FEB, 7),
-        2009: (JAN, 26),
-        2010: (FEB, 14),
-        2011: (FEB, 3),
-        2012: (JAN, 23),
-        2013: (FEB, 10),
-        2014: (JAN, 31),
-        2015: (FEB, 19),
-        2016: (FEB, 8),
-        2017: (JAN, 28),
-        2018: (FEB, 16),
-        2019: (FEB, 5),
-        2020: (JAN, 25),
-        2021: (FEB, 12),
-        2022: (FEB, 1),
-        2023: (JAN, 22),
-        2024: (FEB, 10),
-        2025: (JAN, 29),
-    }
+    LUNAR_NEW_YEAR_DATES_CONFIRMED_YEARS = (2001, 2025)
 
 
 class MalaysiaHinduHolidays(_CustomHinduHolidays):
@@ -682,62 +656,39 @@ class MalaysiaHinduHolidays(_CustomHinduHolidays):
 
 
 class MalaysiaIslamicHolidays(_CustomIslamicHolidays):
+    EID_AL_ADHA_DATES_CONFIRMED_YEARS = (2001, 2025)
     EID_AL_ADHA_DATES = {
         2001: (MAR, 6),
         2002: (FEB, 23),
         2003: (FEB, 12),
         2004: (FEB, 2),
-        2005: (JAN, 21),
-        2006: ((JAN, 10), (DEC, 31)),
-        2007: (DEC, 20),
         2008: (DEC, 9),
         2009: (NOV, 28),
         2010: (NOV, 17),
         2011: (NOV, 7),
-        2012: (OCT, 26),
-        2013: (OCT, 15),
         2014: (OCT, 5),
         2015: (SEP, 24),
         2016: (SEP, 12),
-        2017: (SEP, 1),
         2018: (AUG, 22),
-        2019: (AUG, 11),
-        2020: (JUL, 31),
-        2021: (JUL, 20),
         2022: (JUL, 10),
         2023: (JUN, 29),
         2024: (JUN, 17),
         2025: (JUN, 7),
     }
 
+    EID_AL_FITR_DATES_CONFIRMED_YEARS = (2001, 2025)
     EID_AL_FITR_DATES = {
         2001: (DEC, 17),
         2002: (DEC, 6),
         2003: (NOV, 26),
-        2004: (NOV, 14),
-        2005: (NOV, 3),
         2006: (OCT, 24),
-        2007: (OCT, 13),
-        2008: (OCT, 1),
-        2009: (SEP, 20),
-        2010: (SEP, 10),
         2011: (AUG, 31),
-        2012: (AUG, 19),
-        2013: (AUG, 8),
-        2014: (JUL, 28),
-        2015: (JUL, 17),
-        2016: (JUL, 6),
-        2017: (JUN, 25),
-        2018: (JUN, 15),
         2019: (JUN, 5),
-        2020: (MAY, 24),
-        2021: (MAY, 13),
-        2022: (MAY, 2),
         2023: (APR, 22),
-        2024: (APR, 10),
         2025: (MAR, 31),
     }
 
+    HARI_HOL_JOHOR_DATES_CONFIRMED_YEARS = (2011, 2025)
     HARI_HOL_JOHOR_DATES = {
         2011: (JAN, 12),
         2012: (DEC, 20),
@@ -746,93 +697,48 @@ class MalaysiaIslamicHolidays(_CustomIslamicHolidays):
         2015: (NOV, 19),
         2016: (NOV, 7),
         2017: (OCT, 27),
-        2018: (OCT, 15),
-        2019: (OCT, 5),
         2020: (SEP, 24),
-        2021: (SEP, 13),
         2022: (SEP, 3),
         2023: (AUG, 23),
         2024: (AUG, 11),
-        2025: (JUL, 31),
     }
 
+    HIJRI_NEW_YEAR_DATES_CONFIRMED_YEARS = (2001, 2025)
     HIJRI_NEW_YEAR_DATES = {
-        2001: (MAR, 26),
-        2002: (MAR, 15),
         2003: (MAR, 5),
         2004: (FEB, 22),
-        2005: (FEB, 10),
-        2006: (JAN, 31),
-        2007: (JAN, 20),
-        2008: ((JAN, 10), (DEC, 29)),
-        2009: (DEC, 18),
         2010: (DEC, 8),
         2011: (NOV, 27),
-        2012: (NOV, 15),
         2013: (NOV, 5),
-        2014: (OCT, 25),
-        2015: (OCT, 14),
-        2016: (OCT, 2),
         2017: (SEP, 22),
-        2018: (SEP, 11),
         2019: (SEP, 1),
-        2020: (AUG, 20),
         2021: (AUG, 10),
-        2022: (JUL, 30),
-        2023: (JUL, 19),
-        2024: (JUL, 7),
         2025: (JUN, 27),
     }
 
+    ISRA_AND_MIRAJ_DATES_CONFIRMED_YEARS = (2001, 2025)
     ISRA_AND_MIRAJ_DATES = {
         2001: (OCT, 15),
-        2002: (OCT, 4),
-        2003: (SEP, 24),
-        2004: (SEP, 12),
-        2005: (SEP, 1),
         2006: (AUG, 22),
         2007: (AUG, 11),
         2008: (JUL, 31),
-        2009: (JUL, 20),
-        2010: (JUL, 9),
-        2011: (JUN, 29),
-        2012: (JUN, 17),
-        2013: (JUN, 6),
         2014: (MAY, 27),
-        2015: (MAY, 16),
         2016: (MAY, 5),
-        2017: (APR, 24),
         2018: (APR, 14),
-        2019: (APR, 3),
-        2020: (MAR, 22),
-        2021: (MAR, 11),
         2022: (MAR, 1),
-        2023: (FEB, 18),
-        2024: (FEB, 8),
-        2025: (JAN, 27),
     }
 
+    MAWLID_DATES_CONFIRMED_YEARS = (2001, 2025)
     MAWLID_DATES = {
-        2001: (JUN, 4),
-        2002: (MAY, 24),
         2003: (MAY, 14),
         2004: (MAY, 2),
-        2005: (APR, 21),
         2006: (APR, 11),
-        2007: (MAR, 31),
-        2008: (MAR, 20),
-        2009: (MAR, 9),
-        2010: (FEB, 26),
         2011: (FEB, 16),
         2012: (FEB, 5),
-        2013: (JAN, 24),
         2014: (JAN, 14),
         2015: ((JAN, 3), (DEC, 24)),
         2016: (DEC, 12),
         2017: (DEC, 1),
-        2018: (NOV, 20),
-        2019: (NOV, 9),
-        2020: (OCT, 29),
         2021: (OCT, 19),
         2022: (OCT, 10),
         2023: (SEP, 28),
@@ -840,58 +746,31 @@ class MalaysiaIslamicHolidays(_CustomIslamicHolidays):
         2025: (SEP, 5),
     }
 
+    NUZUL_AL_QURAN_DATES_CONFIRMED_YEARS = (2001, 2025)
     NUZUL_AL_QURAN_DATES = {
         2001: (DEC, 3),
-        2002: (NOV, 22),
         2003: (NOV, 12),
         2004: (NOV, 1),
         2005: (OCT, 21),
-        2006: (OCT, 10),
-        2007: (SEP, 29),
         2008: (SEP, 18),
-        2009: (SEP, 7),
-        2010: (AUG, 27),
-        2011: (AUG, 17),
-        2012: (AUG, 5),
-        2013: (JUL, 25),
         2014: (JUL, 15),
-        2015: (JUL, 4),
-        2016: (JUN, 22),
-        2017: (JUN, 12),
         2018: (JUN, 2),
-        2019: (MAY, 22),
-        2020: (MAY, 10),
-        2021: (APR, 29),
         2022: (APR, 19),
-        2023: (APR, 8),
         2024: (MAR, 28),
         2025: (MAR, 18),
     }
 
+    RAMADAN_BEGINNING_DATES_CONFIRMED_YEARS = (2001, 2025)
     RAMADAN_BEGINNING_DATES = {
         2001: (NOV, 17),
-        2002: (NOV, 6),
         2003: (OCT, 27),
         2004: (OCT, 16),
         2005: (OCT, 5),
-        2006: (SEP, 24),
-        2007: (SEP, 13),
         2008: (SEP, 2),
-        2009: (AUG, 22),
-        2010: (AUG, 11),
-        2011: (AUG, 1),
-        2012: (JUL, 20),
-        2013: (JUL, 9),
         2014: (JUN, 29),
-        2015: (JUN, 18),
         2016: (JUN, 7),
-        2017: (MAY, 27),
         2018: (MAY, 17),
-        2019: (MAY, 6),
-        2020: (APR, 24),
-        2021: (APR, 13),
         2022: (APR, 3),
-        2023: (MAR, 23),
         2024: (MAR, 12),
         2025: (MAR, 2),
     }
