@@ -4,28 +4,26 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
-from datetime import date
 from gettext import gettext as tr
 
-from holidays.calendars.gregorian import APR, AUG, _timedelta
 from holidays.constants import OPTIONAL, PUBLIC
 from holidays.groups import ChristianHolidays, InternationalHolidays
-from holidays.holiday_base import HolidayBase
+from holidays.observed_holiday_base import ObservedHolidayBase, SUN_TO_PREV_SAT, SUN_TO_NEXT_MON
 
 
-class Netherlands(HolidayBase, ChristianHolidays, InternationalHolidays):
+class Netherlands(ObservedHolidayBase, ChristianHolidays, InternationalHolidays):
     """Netherlands holidays.
 
     References:
         * <https://en.wikipedia.org/wiki/Public_holidays_in_the_Netherlands>
         * <https://nl.wikipedia.org/wiki/Feestdagen_in_Nederland>
-        * <http://www.iamsterdam.com/en/plan-your-trip/practical-info/public-holidays>
+        * <https://web.archive.org/web/20250427131819/https://www.iamsterdam.com/en/plan-your-trip/practical-info/public-holidays>
     """
 
     country = "NL"
@@ -37,6 +35,7 @@ class Netherlands(HolidayBase, ChristianHolidays, InternationalHolidays):
     def __init__(self, *args, **kwargs):
         ChristianHolidays.__init__(self)
         InternationalHolidays.__init__(self)
+        kwargs.setdefault("observed_rule", SUN_TO_NEXT_MON)
         super().__init__(*args, **kwargs)
 
     def _populate_public_holidays(self):
@@ -49,7 +48,6 @@ class Netherlands(HolidayBase, ChristianHolidays, InternationalHolidays):
         # Easter Monday.
         self._add_easter_monday(tr("Tweede paasdag"))
 
-        # King's / Queen's day
         if self._year >= 1891:
             name = (
                 # King's Day.
@@ -59,14 +57,12 @@ class Netherlands(HolidayBase, ChristianHolidays, InternationalHolidays):
                 else tr("Koninginnedag")
             )
             if self._year >= 2014:
-                dt = date(self._year, APR, 27)
+                dt = self._add_holiday_apr_27(name)
             elif self._year >= 1949:
-                dt = date(self._year, APR, 30)
+                dt = self._add_holiday_apr_30(name)
             else:
-                dt = date(self._year, AUG, 31)
-            if self._is_sunday(dt):
-                dt = _timedelta(dt, -1 if self._year >= 1980 else +1)
-            self._add_holiday(name, dt)
+                dt = self._add_holiday_aug_31(name)
+            self._move_holiday(dt, rule=SUN_TO_PREV_SAT if self._year >= 1980 else SUN_TO_NEXT_MON)
 
         if self._year >= 1950 and self._year % 5 == 0:
             # Liberation Day.
