@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -28,28 +28,29 @@ class NewZealand(ObservedHolidayBase, ChristianHolidays, InternationalHolidays,
 
     country = "NZ"
     observed_label = "%s (observed)"
+    start_year = 1894
     subdivisions = (
         # ISO 3166-2: Regions and Special Island Authorities.
         # https://en.wikipedia.org/wiki/ISO_3166-2:NZ
-        "AUK",  # Auckland / Tāmaki-makaurau
-        "BOP",  # Bay of Plenty / Toi Moana
-        "CAN",  # Canterbury / Waitaha
-        "CIT",  # Chatham Islands Territory / Wharekauri
-        "GIS",  # Gisborne / Te Tairāwhiti
-        "HKB",  # Hawke's Bay / Te Matau a Māui
-        "MBH",  # Marlborough
-        "MWT",  # Manawatū-Whanganui / Manawatū Whanganui
-        "NSN",  # Nelson / Whakatū
-        "NTL",  # Northland / Te Tai tokerau
-        "OTA",  # Otago / Ō Tākou
-        "STL",  # Southland / Te Taiao Tonga
-        "TAS",  # Tasman / Te tai o Aorere
-        "TKI",  # Taranaki
-        "WGN",  # Greater Wellington / Te Pane Matua Taiao
-        "WKO",  # Waikato
-        "WTC",  # West Coast / Te Tai o Poutini
+        "AUK",  # Auckland (Tāmaki-Makaurau).
+        "BOP",  # Bay of Plenty (Toi Moana).
+        "CAN",  # Canterbury (Waitaha).
+        "CIT",  # Chatham Islands Territory (Wharekauri).
+        "GIS",  # Gisborne (Te Tairāwhiti).
+        "HKB",  # Hawke's Bay (Te Matau-a-Māui).
+        "MBH",  # Marlborough (Manawatū-Whanganui).
+        "MWT",  # Manawatū-Whanganui (Manawatū Whanganui).
+        "NSN",  # Nelson (Whakatū).
+        "NTL",  # Northland (Te Taitokerau).
+        "OTA",  # Otago (Ō Tākou).
+        "STL",  # Southland (Te Taiao Tonga).
+        "TAS",  # Tasman (Te tai o Aorere).
+        "TKI",  # Taranaki (Taranaki).
+        "WGN",  # Greater Wellington (Te Pane Matua Taiao).
+        "WKO",  # Waikato (Waikato).
+        "WTC",  # West Coast (Te Tai o Poutini).
         # Subregions:
-        # https://www.govt.nz/browse/work/public-holidays-and-work/public-holidays-and-anniversary-dates/
+        # https://web.archive.org/web/20250415230521/https://www.govt.nz/browse/work/public-holidays-and-work/public-holidays-and-anniversary-dates/
         "South Canterbury",
     )
     subdivisions_aliases = {
@@ -114,7 +115,6 @@ class NewZealand(ObservedHolidayBase, ChristianHolidays, InternationalHolidays,
         "STC",  # For 'South Canterbury' Subregional Holidays.
         "WTL",  # Westland, Correct code is WTC (for West Coast).
     )
-    start_year = 1894
 
     def __init__(self, *args, **kwargs):
         ChristianHolidays.__init__(self)
@@ -175,7 +175,7 @@ class NewZealand(ObservedHolidayBase, ChristianHolidays, InternationalHolidays,
             elif self._year >= 1912:
                 self._add_holiday_jun_3(name)  # George V
             else:
-                # http://paperspast.natlib.govt.nz/cgi-bin/paperspast?a=d&d=NZH19091110.2.67
+                # https://web.archive.org/web/20250427125629/https://paperspast.natlib.govt.nz/cgi-bin/paperspast?a=d&d=NZH19091110.2.67
                 self._add_holiday_nov_9(name)  # Edward VII
 
         # Matariki
@@ -212,8 +212,8 @@ class NewZealand(ObservedHolidayBase, ChristianHolidays, InternationalHolidays,
             2051: (JUN, 30),
             2052: (JUN, 21),
         }
-        if self._year in dates_obs:
-            self._add_holiday("Matariki", dates_obs[self._year])
+        if dt := dates_obs.get(self._year):
+            self._add_holiday("Matariki", dt)
 
         # Labour Day
         if self._year >= 1900:
