@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -22,45 +22,43 @@ class Portugal(HolidayBase, ChristianHolidays, InternationalHolidays):
 
     References:
         * <https://en.wikipedia.org/wiki/Public_holidays_in_Portugal>
-        * [Labour Day](https://www.e-konomista.pt/dia-do-trabalhador/)
+        * [Labour Day](https://web.archive.org/web/20240502184140/https://www.e-konomista.pt/dia-do-trabalhador/)
         * Portugal Day - Decreto 17.171
         * Restoration of Independence Day - Gazeta de Lisboa, 8 de Dezembro
             de 1823 (n.º 290), pp. 1789 e 1790
         * Azores:
-            * <https://files.dre.pt/1s/1980/08/19200/23052305.pdf>
+            * <https://web.archive.org/web/20240811191206/https://files.dre.pt/1s/1980/08/19200/23052305.pdf>
         * Madeira:
-            * <https://files.dre.pt/1s/1979/11/25900/28782878.pdf>
-            * <https://files.dre.pt/1s/1989/02/02800/04360436.pdf>
-            * <https://files.dre.pt/1s/2002/11/258a00/71837183.pdf>
+            * <https://web.archive.org/web/20230729205620/https://files.dre.pt/1s/1979/11/25900/28782878.pdf>
+            * <https://web.archive.org/web/20230730094358/https://files.dre.pt/1s/1989/02/02800/04360436.pdf>
+            * <https://web.archive.org/web/20230729210821/https://files.dre.pt/1s/2002/11/258a00/71837183.pdf>
     """
 
     country = "PT"
     default_language = "pt_PT"
     supported_categories = (OPTIONAL, PUBLIC)
     start_year = 1801
-
-    # https://en.wikipedia.org/wiki/ISO_3166-2:PT
     subdivisions = (
-        "01",
-        "02",
-        "03",
-        "04",
-        "05",
-        "06",
-        "07",
-        "08",
-        "09",
-        "10",
-        "11",
-        "12",
-        "13",
-        "14",
-        "15",
-        "16",
-        "17",
-        "18",
-        "20",
-        "30",
+        "01",  # Aveiro.
+        "02",  # Beja.
+        "03",  # Braga.
+        "04",  # Bragança.
+        "05",  # Castelo Branco.
+        "06",  # Coimbra.
+        "07",  # Évora.
+        "08",  # Faro.
+        "09",  # Guarda.
+        "10",  # Leiria.
+        "11",  # Lisboa.
+        "12",  # Portalegre.
+        "13",  # Porto.
+        "14",  # Santarém.
+        "15",  # Setúbal.
+        "16",  # Viana do Castelo.
+        "17",  # Vila Real.
+        "18",  # Viseu.
+        "20",  # Região Autónoma dos Açores.
+        "30",  # Região Autónoma da Madeira.
     )
     subdivisions_aliases = {
         "Aveiro": "01",
@@ -84,8 +82,8 @@ class Portugal(HolidayBase, ChristianHolidays, InternationalHolidays):
         "Região Autónoma dos Açores": "20",
         "Região Autónoma da Madeira": "30",
     }
-    _deprecated_subdivisions = ("Ext",)
     supported_languages = ("en_US", "pt_PT", "uk")
+    _deprecated_subdivisions = ("Ext",)
 
     def __init__(self, *args, **kwargs) -> None:
         ChristianHolidays.__init__(self)
@@ -105,7 +103,7 @@ class Portugal(HolidayBase, ChristianHolidays, InternationalHolidays):
         # Easter Sunday.
         self._add_easter_sunday(tr("Páscoa"))
 
-        # Revoked holidays in 2013–2015.
+        # Revoked holidays in 2013-2015.
         if self._year <= 2012 or self._year >= 2016:
             # Corpus Christi.
             self._add_corpus_christi_day(tr("Corpo de Deus"))
