@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -19,10 +19,10 @@ class SouthAfrica(ObservedHolidayBase, ChristianHolidays, InternationalHolidays,
     """South Africa holidays.
 
     References:
-        * <https://www.gov.za/about-sa/public-holidays>
+        * <https://web.archive.org/web/20250424073852/https://www.gov.za/about-sa/public-holidays>
         * <https://en.wikipedia.org/wiki/Public_holidays_in_South_Africa>
-        * <https://www.gov.za/speeches/president-cyril-ramaphosa-progress-economic-recovery-30-oct-2023-0000>
-        * <https://www.gov.za/documents/notices/public-holidays-act-declaration-29-may-2024-public-holiday-23-feb-2024>
+        * <https://web.archive.org/web/20240715110800/https://www.gov.za/speeches/president-cyril-ramaphosa-progress-economic-recovery-30-oct-2023-0000>
+        * <https://web.archive.org/web/20250427184315/https://www.gov.za/documents/notices/public-holidays-act-declaration-29-may-2024-public-holiday-23-feb-2024>
     """
 
     country = "ZA"
@@ -152,6 +152,6 @@ class SouthAfricaStaticHolidays:
     }
 
     special_public_holidays_observed = {
-        # Special holiday http://tiny.cc/za_y2k
+        # https://web.archive.org/web/20120328122217/http://www.info.gov.za/speeches/1999/991028409p1002.htm
         2000: (JAN, 3, y2k_changeover),
     }
