@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -14,7 +14,7 @@ import warnings
 from datetime import date
 from gettext import gettext as tr
 
-from holidays.calendars import _CustomChineseHolidays
+from holidays.calendars.chinese import KOREAN_CALENDAR
 from holidays.calendars.gregorian import (
     JAN,
     FEB,
@@ -55,19 +55,19 @@ class SouthKorea(
 
     References:
         * <https://en.wikipedia.org/wiki/Public_holidays_in_South_Korea>
-        * <https://www.law.go.kr/법령/관공서의%20공휴일에%20관한%20규정>
-        * <https://elaw.klri.re.kr/eng_service/lawView.do?lang=ENG&hseq=34678>
-        * <https://elaw.klri.re.kr/eng_service/%20lawView.do?hseq=38405&lang=ENG>
+        * <https://web.archive.org/web/20240429121214/https://www.law.go.kr/법령/관공서의%20공휴일에%20관한%20규정>
+        * <https://web.archive.org/web/20250429081641/https://elaw.klri.re.kr/eng_service/lawView.do?lang=ENG&hseq=34678>
+        * <https://web.archive.org/web/20250123212346/https://elaw.klri.re.kr/eng_service/%20lawView.do?hseq=38405&lang=ENG>
         * <https://namu.wiki/w/대통령%20선거일>
         * <https://namu.wiki/w/공휴일/대한민국>
         * <https://namu.wiki/w/공휴일/대한민국/역사>
         * <https://namu.wiki/w/대체%20휴일%20제도>
-        * [TH localization 1](https://overseas.mofa.go.kr/th-th/wpge/m_3133/contents.do)
-        * [TH localization 2](https://thailand.korean-culture.org/th/138/korea/38)
+        * [TH localization 1](https://web.archive.org/web/20241217184803/https://overseas.mofa.go.kr/th-th/wpge/m_3133/contents.do)
+        * [TH localization 2](https://web.archive.org/web/20200216004120/http://thailand.korean-culture.org:80/th/138/korea/38)
 
     Checked With:
-        * <https://publicholidays.co.kr/ko/2020-dates/>
-        * <https://publicholidays.co.kr/ko/2022-dates/>
+        * <https://web.archive.org/web/20231202051034/https://publicholidays.co.kr/ko/2020-dates/>
+        * <https://web.archive.org/web/20231002172705/https://publicholidays.co.kr/ko/2022-dates/>
 
     According to (3), the alt holidays in Korea are as follows:
         * The alt holiday means next first non holiday after the holiday.
@@ -87,7 +87,7 @@ class SouthKorea(
     start_year = 1948
 
     def __init__(self, *args, **kwargs):
-        ChineseCalendarHolidays.__init__(self, cls=SouthKoreaLunisolarHolidays)
+        ChineseCalendarHolidays.__init__(self, calendar=KOREAN_CALENDAR)
         ChristianHolidays.__init__(self)
         InternationalHolidays.__init__(self)
         StaticHolidays.__init__(self, cls=SouthKoreaStaticHolidays)
@@ -289,34 +289,6 @@ class KOR(SouthKorea):
     pass
 
 
-class SouthKoreaLunisolarHolidays(_CustomChineseHolidays):
-    BUDDHA_BIRTHDAY_DATES = {
-        1931: (MAY, 25),
-        1968: (MAY, 5),
-        2001: (MAY, 1),
-        2012: (MAY, 28),
-        2023: (MAY, 27),
-        2025: (MAY, 5),
-    }
-
-    LUNAR_NEW_YEAR_DATES = {
-        1916: (FEB, 4),
-        1944: (JAN, 26),
-        1954: (FEB, 4),
-        1958: (FEB, 19),
-        1966: (JAN, 22),
-        1988: (FEB, 18),
-        1997: (FEB, 8),
-        2027: (FEB, 7),
-        2028: (JAN, 27),
-    }
-
-    MID_AUTUMN_DATES = {
-        1942: (SEP, 25),
-        2040: (SEP, 21),
-    }
-
-
 class SouthKoreaStaticHolidays:
     """South Korea special holidays.
 
