@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -53,21 +53,22 @@ class Taiwan(ObservedHolidayBase, ChineseCalendarHolidays, InternationalHolidays
         * <https://en.wikipedia.org/wiki/Public_holidays_in_Taiwan>
 
     Commemorative Day and Day Implementation Method Amendments:
-        * [Ministry of Interior (87) Order No. 8706459](https://zh.wikisource.org/wiki/紀念日及節日實施辦法_(民國87年))
-        * [Ministry of Interior (88) Order No. 8897074](https://zh.wikisource.org/wiki/紀念日及節日實施辦法_(民國88年))
-        * [Ministry of Interior (89) Order No. 8972185](https://zh.wikisource.org/wiki/紀念日及節日實施辦法_(民國89年2月))
-        * [Ministry of Interior (89) Order No. 8962562](https://zh.wikisource.org/wiki/紀念日及節日實施辦法_(民國89年12月))
-        * [Ministry of Interior Order No. 0950045320](https://law.moj.gov.tw/LawClass/LawOldVer.aspx?pcode=D0020033&lnndate=20060309&lser=001)
-        * [Ministry of Interior Order No. 0960110433](https://law.moj.gov.tw/LawClass/LawOldVer.aspx?pcode=D0020033&lnndate=20070711&lser=001)
-        * [Ministry of Interior Order No. 0960131407](https://law.moj.gov.tw/LawClass/LawOldVer.aspx?pcode=D0020033&lnndate=20070711&lser=001)
-        * [Ministry of Interior Order No. 0960155673](https://law.moj.gov.tw/LawClass/LawOldVer.aspx?pcode=D0020033&lnndate=20071003&lser=001)
-        * [Ministry of Interior Order No. 0990212117](https://law.moj.gov.tw/LawClass/LawOldVer.aspx?pcode=D0020033&lnndate=20101102&lser=001)
-        * [Ministry of Interior Order No. 1010307327 and 1030128812](https://law.moj.gov.tw/LawClass/LawOldVer.aspx?pcode=D0020033&lnndate=20120925&lser=001)
-        * [Ministry of Interior Order No. 1030182404](https://law.moj.gov.tw/LawClass/LawAll.aspx?pcode=D0020033)
+        * [Ministry of Interior (87) Order No. 8706459](https://web.archive.org/web/20250501035936/https://zh.wikisource.org/wiki/紀念日及節日實施辦法_(民國87年))
+        * [Ministry of Interior (88) Order No. 8897074](https://web.archive.org/web/20250429134107/https://zh.wikisource.org/wiki/紀念日及節日實施辦法_(民國88年))
+        * [Ministry of Interior (89) Order No. 8972185](https://web.archive.org/web/20250429134119/https://zh.wikisource.org/wiki/紀念日及節日實施辦法_(民國89年2月))
+        * [Ministry of Interior (89) Order No. 8962562](https://web.archive.org/web/20250429134023/https://zh.wikisource.org/wiki/紀念日及節日實施辦法_(民國89年12月))
+        * [Ministry of Interior Order No. 0950045320](https://web.archive.org/web/20240916001724/https://law.moj.gov.tw/LawClass/LawOldVer.aspx?pcode=D0020033&lnndate=20060309&lser=001)
+        * [Ministry of Interior Order No. 0960110433](https://web.archive.org/web/20240915222212/https://law.moj.gov.tw/LawClass/LawOldVer.aspx?pcode=D0020033&lnndate=20070711&lser=001)
+        * [Ministry of Interior Order No. 0960131407](https://web.archive.org/web/20240915222212/https://law.moj.gov.tw/LawClass/LawOldVer.aspx?pcode=D0020033&lnndate=20070711&lser=001)
+        * [Ministry of Interior Order No. 0960155673](https://web.archive.org/web/20240916000901/https://law.moj.gov.tw/LawClass/LawOldVer.aspx?pcode=D0020033&lnndate=20071003&lser=001)
+        * [Ministry of Interior Order No. 0990212117](https://web.archive.org/web/20240916004712/https://law.moj.gov.tw/LawClass/LawOldVer.aspx?pcode=D0020033&lnndate=20101102&lser=001)
+        * [Ministry of Interior Order No. 1010307327 and 1030128812](https://web.archive.org/web/20240919205138/https://law.moj.gov.tw/LawClass/LawOldVer.aspx?pcode=D0020033&lnndate=20120925&lser=001)
+        * [Ministry of Interior Order No. 1030182404](https://web.archive.org/web/20250227171607/https://law.moj.gov.tw/LawClass/LawAll.aspx?pcode=D0020033)
+        * [Decree No. 11400053171](https://web.archive.org/web/20250602210918/https://law.moj.gov.tw/News/newsdetail.aspx?msgid=191745)
 
     Checked With:
-        * [DGPA Work Calendar (1998-2025; Chinese)](https://www.dgpa.gov.tw/informationlist?uid=30)
-        * [DGPA Work Calendar (2001-2025; English)](https://www.dgpa.gov.tw/en/informationlist?uid=353)
+        * [DGPA Work Calendar (1998-2025; Chinese)](https://web.archive.org/web/20250307201828/https://www.dgpa.gov.tw/informationlist?uid=30)
+        * [DGPA Work Calendar (2001-2025; English)](https://web.archive.org/web/20240606012108/http://www.dgpa.gov.tw/en/informationlist?uid=353)
     """
 
     country = "TW"
@@ -123,7 +124,10 @@ class Taiwan(ObservedHolidayBase, ChineseCalendarHolidays, InternationalHolidays
             self._add_observed(self._next_year_new_years_day, name=name)
 
         # Chinese New Year's Eve.
-        dts_observed_forward.add(self._add_chinese_new_years_eve(tr("農曆除夕")))
+        name = tr("農曆除夕")
+        if self._year >= 2026:
+            dts_observed_forward.add(self._add_chinese_day_before_new_years_eve(name))
+        dts_observed_forward.add(self._add_chinese_new_years_eve(name))
 
         # Chinese New Year.
         name = tr("春節")
@@ -141,15 +145,30 @@ class Taiwan(ObservedHolidayBase, ChineseCalendarHolidays, InternationalHolidays
         # Tomb-Sweeping Day.
         dts_observed.add(self._add_qingming_festival(tr("民族掃墓節")))
 
+        if self._year >= 2026:
+            # Labor Day.
+            self._add_labor_day(tr("勞動節"))
+
         # Dragon Boat Festival.
         dts_observed.add(self._add_dragon_boat_festival(tr("端午節")))
 
         # Mid-Autumn Festival.
         dts_observed.add(self._add_mid_autumn_festival(tr("中秋節")))
 
+        if self._year >= 2025:
+            # Confucius' Birthday.
+            self._add_holiday_sep_28(tr("孔子誕辰紀念日"))
+
         # National Day.
         dts_observed.add(self._add_holiday_oct_10(tr("國慶日")))
 
+        if self._year >= 2025:
+            # Taiwan Restoration and Guningtou Victory Memorial Day.
+            self._add_holiday_oct_25(tr("臺灣光復暨金門古寧頭大捷紀念日"))
+
+            # Constitution Day.
+            self._add_holiday_dec_25(tr("行憲紀念日"))
+
         if self.observed:
             self._populate_observed(dts_observed)
             # While Chinese New Year special observances rule weren't officially decreed
@@ -184,8 +203,9 @@ class Taiwan(ObservedHolidayBase, ChineseCalendarHolidays, InternationalHolidays
             self._add_holiday_mar_29(tr("革命先烈紀念日"))
 
     def _populate_optional_holidays(self):
-        # Labor Day.
-        self._add_labor_day(tr("勞動節"))
+        if self._year <= 2025:
+            # Labor Day.
+            self._add_labor_day(tr("勞動節"))
 
         # Armed Forces Day.
         self._add_holiday_sep_3(tr("軍人節"))
@@ -228,17 +248,19 @@ class Taiwan(ObservedHolidayBase, ChineseCalendarHolidays, InternationalHolidays
             # Revolutionary Martyrs Memorial Day.
             self._add_holiday_mar_29(tr("革命先烈紀念日"))
 
-            # Confucius' Birthday.
-            self._add_holiday_sep_28(tr("孔子誕辰紀念日"))
+            if self._year <= 2024:
+                # Confucius' Birthday.
+                self._add_holiday_sep_28(tr("孔子誕辰紀念日"))
 
-            # Taiwan Retrocession Day.
-            self._add_holiday_oct_25(tr("臺灣光復節"))
+                # Taiwan Retrocession Day.
+                self._add_holiday_oct_25(tr("臺灣光復節"))
 
             # Dr. Sun Yat-sen's Birthday.
             self._add_holiday_nov_12(tr("國父誕辰紀念日"))
 
-            # Constitution Day.
-            self._add_holiday_dec_25(tr("行憲紀念日"))
+            if self._year <= 2024:
+                # Constitution Day.
+                self._add_holiday_dec_25(tr("行憲紀念日"))
 
             if self._year <= 2006:
                 # Late President Chiang Kai-shek's Birthday.
@@ -268,34 +290,34 @@ class TaiwanStaticHolidays:
     """Taiwan special holidays.
 
     DGPA, Executive Yuan Work Calendars:
-        * [1998](https://www.dgpa.gov.tw/information?uid=30&pid=4979)
-        * [1999](https://www.dgpa.gov.tw/information?uid=30&pid=4978)
-        * [2000](https://www.dgpa.gov.tw/information?uid=30&pid=4977)
-        * [2001](https://www.dgpa.gov.tw/en/information?uid=353&pid=6199)
-        * [2002](https://www.dgpa.gov.tw/en/information?uid=353&pid=6198)
-        * [2003](https://www.dgpa.gov.tw/en/information?uid=353&pid=6197)
-        * [2004](https://www.dgpa.gov.tw/en/information?uid=353&pid=6196)
-        * [2005](https://www.dgpa.gov.tw/en/information?uid=353&pid=6195)
-        * [2006](https://www.dgpa.gov.tw/en/information?uid=353&pid=6192)
-        * [2007](https://www.dgpa.gov.tw/en/information?uid=353&pid=6194)
-        * [2008](https://www.dgpa.gov.tw/en/information?uid=353&pid=6191)
-        * [2009](https://www.dgpa.gov.tw/en/information?uid=353&pid=6190)
-        * [2010](https://www.dgpa.gov.tw/en/information?uid=353&pid=6189)
-        * [2011](https://www.dgpa.gov.tw/en/information?uid=353&pid=6188)
-        * [2012](https://www.dgpa.gov.tw/en/information?uid=353&pid=6187)
-        * [2013](https://www.dgpa.gov.tw/en/information?uid=353&pid=6186)
-        * [2014](https://www.dgpa.gov.tw/en/information?uid=353&pid=6183)
-        * [2015](https://www.dgpa.gov.tw/en/information?uid=353&pid=6182)
-        * [2016](https://www.dgpa.gov.tw/en/information?uid=353&pid=6180)
-        * [2017](https://www.dgpa.gov.tw/en/information?uid=353&pid=6178)
-        * [2018](https://www.dgpa.gov.tw/en/information?uid=353&pid=7730)
-        * [2019](https://www.dgpa.gov.tw/en/information?uid=353&pid=8178)
-        * [2020](https://www.dgpa.gov.tw/en/information?uid=353&pid=9724)
-        * [2021](https://www.dgpa.gov.tw/en/information?uid=353&pid=10181)
-        * [2022](https://www.dgpa.gov.tw/en/information?uid=353&pid=10659)
-        * [2023](https://www.dgpa.gov.tw/en/information?uid=353&pid=11016)
-        * [2024](https://www.dgpa.gov.tw/en/information?uid=353&pid=11402)
-        * [2025](https://www.dgpa.gov.tw/en/information?uid=353&pid=11979)
+        * [1998](https://web.archive.org/web/20240119034602/https://www.dgpa.gov.tw/information?pid=4979&uid=30)
+        * [1999](https://web.archive.org/web/20240119034606/https://www.dgpa.gov.tw/information?pid=4978&uid=30)
+        * [2000](https://web.archive.org/web/20231230164623/https://www.dgpa.gov.tw/information?uid=30&pid=4977)
+        * [2001](https://web.archive.org/web/20220809165413/https://www.dgpa.gov.tw/en/information?uid=353&pid=6199)
+        * [2002](https://web.archive.org/web/20220809163821/https://www.dgpa.gov.tw/en/information?uid=353&pid=6198)
+        * [2003](https://web.archive.org/web/20220809161706/https://www.dgpa.gov.tw/en/information?uid=353&pid=6197)
+        * [2004](https://web.archive.org/web/20220809175339/https://www.dgpa.gov.tw/en/information?uid=353&pid=6196)
+        * [2005](https://web.archive.org/web/20220809173619/https://www.dgpa.gov.tw/en/information?uid=353&pid=6195)
+        * [2006](https://web.archive.org/web/20250427175035/https://www.dgpa.gov.tw/en/information?uid=353&pid=6192)
+        * [2007](https://web.archive.org/web/20250427175157/https://www.dgpa.gov.tw/en/information?uid=353&pid=6194)
+        * [2008](https://web.archive.org/web/20250427175031/https://www.dgpa.gov.tw/en/information?uid=353&pid=6191)
+        * [2009](https://web.archive.org/web/20250427175008/https://www.dgpa.gov.tw/en/information?uid=353&pid=6190)
+        * [2010](https://web.archive.org/web/20240913193941/https://www.dgpa.gov.tw/en/information?pid=6189&uid=353)
+        * [2011](https://web.archive.org/web/20250427175006/https://www.dgpa.gov.tw/en/information?uid=353&pid=6188)
+        * [2012](https://web.archive.org/web/20250427175006/https://www.dgpa.gov.tw/en/information?uid=353&pid=6187)
+        * [2013](https://web.archive.org/web/20250427174956/https://www.dgpa.gov.tw/en/information?uid=353&pid=6186)
+        * [2014](https://web.archive.org/web/20220809133242/https://www.dgpa.gov.tw/en/information?uid=353&pid=6183)
+        * [2015](https://web.archive.org/web/20220809133240/https://www.dgpa.gov.tw/en/information?uid=353&pid=6182)
+        * [2016](https://web.archive.org/web/20220809133238/https://www.dgpa.gov.tw/en/information?uid=353&pid=6180)
+        * [2017](https://web.archive.org/web/20220809133236/https://www.dgpa.gov.tw/en/information?uid=353&pid=6178)
+        * [2018](https://web.archive.org/web/20240518122217/https://www.dgpa.gov.tw/en/information?uid=353&pid=7730)
+        * [2019](https://web.archive.org/web/20240422121421/http://www.dgpa.gov.tw/en/information?uid=353&pid=8178)
+        * [2020](https://web.archive.org/web/20240914094053/https://www.dgpa.gov.tw/en/information?pid=9724&uid=353)
+        * [2021](https://web.archive.org/web/20240615041915/https://www.dgpa.gov.tw/en/information?uid=353&pid=10181)
+        * [2022](https://web.archive.org/web/20220809133226/https://www.dgpa.gov.tw/en/information?uid=353&pid=10659)
+        * [2023](https://web.archive.org/web/20220809133225/https://www.dgpa.gov.tw/en/information?uid=353&pid=11016)
+        * [2024](https://web.archive.org/web/20250414165829/https://www.dgpa.gov.tw/en/information?uid=353&pid=11402)
+        * [2025](https://web.archive.org/web/20250121091032/https://www.dgpa.gov.tw/en/information?uid=353&pid=11979)
     """
 
     # Date format (see strftime() Format Codes).
