@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -46,105 +46,105 @@ class Thailand(ObservedHolidayBase, InternationalHolidays, StaticHolidays, ThaiC
 
     References:
         * <https://en.wikipedia.org/wiki/Public_holidays_in_Thailand>
-        * [Holidays Act (MAR 1914)](https://ratchakitcha.soc.go.th/documents/1044125.pdf)
-        * [Special Extension for MoJ (In-effect 1915 onwards)](https://ratchakitcha.soc.go.th/documents/1046008.pdf)
-        * [Holidays Act Amendment (MAR 1926)](https://ratchakitcha.soc.go.th/documents/1073133.pdf)
-        * [Ascension of HM King Ananda Mahidol (MAR 1935)](https://th.wikisource.org/wiki/ประกาศนายกรัฐมนตรี_ลงวันที่_7_มีนาคม_2477_(รก.))
-        * [Holidays Act Amendment (JAN 1938)](https://ratchakitcha.soc.go.th/documents/1105432.pdf)
-        * [Translation Typo Fixed for the JAN 1938 Amendment](https://ratchakitcha.soc.go.th/documents/1105491.pdf)
-        * [Constitution Petition Day renamed National Day (JUL 1938)](https://th.wikisource.org/wiki/ประกาศสำนักนายกรัฐมนตรี_ลงวันที่_18_กรกฎาคม_2481)
-        * [Holidays Act Amendment (MAR 1940)](https://ratchakitcha.soc.go.th/documents/1110471.pdf)
-        * [Holidays Act Amendment (SEP 1940) (In-effect 1941)](https://ratchakitcha.soc.go.th/documents/1111954.pdf)
-        * [Removal of Royal Language for King's Birthday (B.E 2484/1941)](https://th.wikisource.org/wiki/ประกาศสำนักนายกรัฐมนตรี_ลงวันที่_19_กันยายน_2484)
-        * [Holidays Act, Franco-Thai War Armistice Day added (B.E. 2485/1942)](https://ratchakitcha.soc.go.th/documents/1114825.pdf)
-        * [Holidays Act, Franco-Thai War Armistice Day Repealed (B.E. 2487/1944)](https://ratchakitcha.soc.go.th/documents/1121365.pdf)
-        * [Removal of Royal Language for King's Birthday Repealed (B.E 2488/1945)](https://th.wikisource.org/wiki/ประกาศสำนักนายกรัฐมนตรี_ลงวันที่_12_มกราคม_2488)
-        * [Holidays Act Amendment (DEC B.E. 2488/1945)](https://ratchakitcha.soc.go.th/documents/1123218.pdf)
-        * [Holidays Act Amendment (AUG B.E. 2489/1946)](https://ratchakitcha.soc.go.th/documents/1124494.pdf)
-        * [Special Weekend Arrangement for 4 Southern Provinces (4SP)](https://ratchakitcha.soc.go.th/documents/1129175.pdf)
-        * [Holidays Act, B.E. 2491 (1948)](https://ratchakitcha.soc.go.th/documents/1130817.pdf)
-        * [Holidays Act (No. 2), B.E. 2493 (1950)](https://ratchakitcha.soc.go.th/documents/1141392.pdf)
-        * [Holidays Act (No. 3), B.E. 2494 (1951)](https://ratchakitcha.soc.go.th/documents/1143601.pdf)
-        * [HM King Bhumibol Adulyadej Birthday Holidays Adjustment](https://ratchakitcha.soc.go.th/documents/1145614.pdf)
-        * [Holidays Act (No. 4), B.E. 2495 (1952)](https://ratchakitcha.soc.go.th/documents/1148403.pdf)
-        * [Holidays Act (No. 6), B.E. 2497 (1954)](https://ratchakitcha.soc.go.th/documents/1159427.pdf)
-        * [Holidays Act (No. 7), B.E. 2497 (1954); United Nations Day added](https://ratchakitcha.soc.go.th/documents/1160256.pdf)
-        * [Holidays Act (No. 8), B.E. 2499 (1956); Mothers Day, Children's Day added](https://ratchakitcha.soc.go.th/documents/1169783.pdf)
-        * [Holidays Act (No. 9), B.E. 2499 (1956); Weekend is now Buddhist Sabbath-SUN](https://ratchakitcha.soc.go.th/documents/1172667.pdf)
-        * [Holidays Act (No. 10), B.E. 2500 (1957); Weekend Change Reverted](https://ratchakitcha.soc.go.th/documents/1179999.pdf)
-        * [Holidays Act (No. 11), B.E. 2500 (1957)](https://ratchakitcha.soc.go.th/documents/1180042.pdf)
-        * [Holidays Act (No. 12), B.E. 2502 (1959); Weekend is full day SAT-SUN](https://ratchakitcha.soc.go.th/documents/1187876.pdf)
-        * [Holidays Act (No. 13), B.E. 2503 (1960); National Day is now Dec 5](https://ratchakitcha.soc.go.th/documents/1196364.pdf)
-        * [Holidays Act (No. 14), B.E. 2505 (1962); Asarnha Bucha added](https://ratchakitcha.soc.go.th/documents/1206407.pdf)
-        * [Holidays Act (No. 16), B.E. 2506 (1963); 4SP weekend is now SAT-SUN](https://hr.rid.go.th/wp-content/uploads/2022/12/06-16.pdf)
-        * [Eid-al-Fitr and Eit al-Adha added for 4SP](https://hr.rid.go.th/wp-content/uploads/2022/12/05-2517.pdf)
-        * [Holidays Act (No. 17), B.E. 2525 (1982); Chakri Day Full Name Changed](https://ratchakitcha.soc.go.th/documents/1494132.pdf)
-        * [Holidays Act (No. 19), B.E. 2540 (1997); Songkran Date Changed](https://ratchakitcha.soc.go.th/documents/1685580.pdf)
-        * [Holidays Act (No. 20), B.E. 2555 (2012); CNY in 4SP](https://ratchakitcha.soc.go.th/documents/1914282.pdf)
-        * [Holidays Act (No. 21), B.E. 2556 (2013); Songkhla added to 4SP](https://ratchakitcha.soc.go.th/documents/2098813.pdf)
-        * [Holidays Act (No. 22), B.E. 2560 (2017); Father's Day Date Clarification](https://ratchakitcha.soc.go.th/documents/2098828.pdf)
-        * [Holidays Act (No. 23), B.E. 2560 (2017); Rama X's Birthday added](https://ratchakitcha.soc.go.th/documents/2104467.pdf)
-        * [HM Queen Suthida's Birthday added](https://ratchakitcha.soc.go.th/documents/17081602.pdf)
-        * [Holidays Act, B.E. 2562 (2019)](https://ratchakitcha.soc.go.th/documents/17082311.pdf)
+        * [Holidays Act (MAR 1914)](https://web.archive.org/web/20231021231154/https://ratchakitcha.soc.go.th/documents/1044125.pdf)
+        * [Special Extension for MoJ (In-effect 1915 onwards)](https://web.archive.org/web/20250428123805/https://ratchakitcha.soc.go.th/documents/1046008.pdf)
+        * [Holidays Act Amendment (MAR 1926)](https://web.archive.org/web/20231021231328/https://ratchakitcha.soc.go.th/documents/1073133.pdf)
+        * [Ascension of HM King Ananda Mahidol (MAR 1935)](https://web.archive.org/web/20250215164432/https://th.wikisource.org/wiki/ประกาศนายกรัฐมนตรี_ลงวันที่_7_มีนาคม_2477_(รก.))
+        * [Holidays Act Amendment (JAN 1938)](https://web.archive.org/web/20240812112232/https://ratchakitcha.soc.go.th/documents/1105432.pdf)
+        * [Translation Typo Fixed for the JAN 1938 Amendment](https://web.archive.org/web/20250428132201/https://ratchakitcha.soc.go.th/documents/1105491.pdf)
+        * [Constitution Petition Day renamed National Day (JUL 1938)](https://web.archive.org/web/20241109062813/https://th.wikisource.org/wiki/ประกาศสำนักนายกรัฐมนตรี_ลงวันที่_18_กรกฎาคม_2481)
+        * [Holidays Act Amendment (MAR 1940)](https://web.archive.org/web/20240813142812/https://ratchakitcha.soc.go.th/documents/1110471.pdf)
+        * [Holidays Act Amendment (SEP 1940) (In-effect 1941)](https://web.archive.org/web/20231021230955/https://ratchakitcha.soc.go.th/documents/1111954.pdf)
+        * [Removal of Royal Language for King's Birthday (B.E 2484/1941)](https://web.archive.org/web/20241213001307/https://th.wikisource.org/wiki/ประกาศสำนักนายกรัฐมนตรี_ลงวันที่_19_กันยายน_2484)
+        * [Holidays Act, Franco-Thai War Armistice Day added (B.E. 2485/1942)](https://web.archive.org/web/20250428123610/https://ratchakitcha.soc.go.th/documents/1114825.pdf)
+        * [Holidays Act, Franco-Thai War Armistice Day Repealed (B.E. 2487/1944)](https://web.archive.org/web/20250428123653/https://ratchakitcha.soc.go.th/documents/1121365.pdf)
+        * [Removal of Royal Language for King's Birthday Repealed (B.E 2488/1945)](https://web.archive.org/web/20241210051421/https://th.wikisource.org/wiki/ประกาศสำนักนายกรัฐมนตรี_ลงวันที่_12_มกราคม_2488)
+        * [Holidays Act Amendment (DEC B.E. 2488/1945)](https://web.archive.org/web/20231022121809/https://ratchakitcha.soc.go.th/documents/1123218.pdf)
+        * [Holidays Act Amendment (AUG B.E. 2489/1946)](https://web.archive.org/web/20250428132451/https://ratchakitcha.soc.go.th/documents/1124494.pdf)
+        * [Special Weekend Arrangement for 4 Southern Provinces (4SP)](https://web.archive.org/web/20250428133015/https://ratchakitcha.soc.go.th/documents/1129175.pdf)
+        * [Holidays Act, B.E. 2491 (1948)](https://web.archive.org/web/20240812124132/https://ratchakitcha.soc.go.th/documents/1130817.pdf)
+        * [Holidays Act (No. 2), B.E. 2493 (1950)](https://web.archive.org/web/20240812132452/https://ratchakitcha.soc.go.th/documents/1141392.pdf)
+        * [Holidays Act (No. 3), B.E. 2494 (1951)](https://web.archive.org/web/20250428133136/https://ratchakitcha.soc.go.th/documents/1143601.pdf)
+        * [HM King Bhumibol Adulyadej Birthday Holidays Adjustment](https://web.archive.org/web/20250428133250/https://ratchakitcha.soc.go.th/documents/1145614.pdf)
+        * [Holidays Act (No. 4), B.E. 2495 (1952)](https://web.archive.org/web/20250428133326/https://ratchakitcha.soc.go.th/documents/1148403.pdf)
+        * [Holidays Act (No. 6), B.E. 2497 (1954)](https://web.archive.org/web/20240812201729/https://ratchakitcha.soc.go.th/documents/1159427.pdf)
+        * [Holidays Act (No. 7), B.E. 2497 (1954); United Nations Day added](https://web.archive.org/web/20250428133416/https://ratchakitcha.soc.go.th/documents/1160256.pdf)
+        * [Holidays Act (No. 8), B.E. 2499 (1956); Mothers Day, Children's Day added](https://web.archive.org/web/20250428133618/https://ratchakitcha.soc.go.th/documents/1169783.pdf)
+        * [Holidays Act (No. 9), B.E. 2499 (1956); Weekend is now Buddhist Sabbath-SUN](https://web.archive.org/web/20250428133714/https://ratchakitcha.soc.go.th/documents/1172667.pdf)
+        * [Holidays Act (No. 10), B.E. 2500 (1957); Weekend Change Reverted](https://web.archive.org/web/20250428133819/https://ratchakitcha.soc.go.th/documents/1179999.pdf)
+        * [Holidays Act (No. 11), B.E. 2500 (1957)](https://web.archive.org/web/20250428133903/https://ratchakitcha.soc.go.th/documents/1180042.pdf)
+        * [Holidays Act (No. 12), B.E. 2502 (1959); Weekend is full day SAT-SUN](https://web.archive.org/web/20250428134027/https://ratchakitcha.soc.go.th/documents/1187876.pdf)
+        * [Holidays Act (No. 13), B.E. 2503 (1960); National Day is now Dec 5](https://web.archive.org/web/20230627092848/https://ratchakitcha.soc.go.th/documents/1196364.pdf)
+        * [Holidays Act (No. 14), B.E. 2505 (1962); Asarnha Bucha added](https://web.archive.org/web/20250428134121/https://ratchakitcha.soc.go.th/documents/1206407.pdf)
+        * [Holidays Act (No. 16), B.E. 2506 (1963); 4SP weekend is now SAT-SUN](https://archive.org/details/httpshr.rid.go.thwp-contentuploads20221206-16.pdf)
+        * [Eid-al-Fitr and Eit al-Adha added for 4SP](https://archive.org/details/httpshr.rid.go.thwp-contentuploads20221205-2517.pdf)
+        * [Holidays Act (No. 17), B.E. 2525 (1982); Chakri Day Full Name Changed](https://web.archive.org/web/20250428134349/https://ratchakitcha.soc.go.th/documents/1494132.pdf)
+        * [Holidays Act (No. 19), B.E. 2540 (1997); Songkran Date Changed](https://web.archive.org/web/20250428134426/https://ratchakitcha.soc.go.th/documents/1685580.pdf)
+        * [Holidays Act (No. 20), B.E. 2555 (2012); CNY in 4SP](https://web.archive.org/web/20250428134504/https://ratchakitcha.soc.go.th/documents/1914282.pdf)
+        * [Holidays Act (No. 21), B.E. 2556 (2013); Songkhla added to 4SP](https://web.archive.org/web/20250428134536/https://ratchakitcha.soc.go.th/documents/2098813.pdf)
+        * [Holidays Act (No. 22), B.E. 2560 (2017); Father's Day Date Clarification](https://web.archive.org/web/20230627142834/https://ratchakitcha.soc.go.th/documents/2098828.pdf)
+        * [Holidays Act (No. 23), B.E. 2560 (2017); Rama X's Birthday added](https://web.archive.org/web/20250428134706/https://ratchakitcha.soc.go.th/documents/2104467.pdf)
+        * [HM Queen Suthida's Birthday added](https://web.archive.org/web/20250428134748/https://ratchakitcha.soc.go.th/documents/17081602.pdf)
+        * [Holidays Act, B.E. 2562 (2019)](https://web.archive.org/web/20250428134835/https://ratchakitcha.soc.go.th/documents/17082311.pdf)
 
     Checked with:
-        * [Bank of Thailand lists](http://tiny.cc/wa_bot_2023)
+        * [Bank of Thailand](https://web.archive.org/web/20230205072056/https://www.bot.or.th/Thai/FinancialInstitutions/FIholiday/Pages/2023.aspx)
 
     In Lieus:
-        * [isranews.org](http://tiny.cc/wa_isranews_inlieu_hist)
-        * <https://resolution.soc.go.th/?prep_id=99159317>
-        * <https://resolution.soc.go.th/?prep_id=196007>
+        * [isranews.org](https://web.archive.org/web/20230205073547/https://www.isranews.org/content-page/item/20544-วันหยุดชดเชย-มาจากไหน-sp-863880667.html)
+        * <https://web.archive.org/web/20250428135057/https://resolution.soc.go.th/?prep_id=99159317>
+        * <https://web.archive.org/web/20250428151918/https://resolution.soc.go.th/?prep_id=196007>
         * <https://github.com/vacanza/holidays/pull/929>
-        * <https://www.thairath.co.th/lifestyle/life/2812118>
-        * <https://www.thaipbs.or.th/news/content/346216>
+        * <https://web.archive.org/web/20250418080608/https://www.thairath.co.th/lifestyle/life/2812118>
+        * <https://web.archive.org/web/20250408214054/https://www.thaipbs.or.th/news/content/346216>
 
     Certain holidays references:
-        * [New Year's Day](http://tiny.cc/wa_wiki_thai_newyear_2483)
-        * [National Children's Day](https://thainews.prd.go.th/banner/th/children'sday/)
-        * [Chakri Memorial Day](http://tiny.cc/wa_ocac_chakri)
+        * [New Year's Day](https://web.archive.org/web/20230115102900/https://th.wikisource.org/wiki/ประกาศให้ใช้วันที่_1_มกราคม_เป็นวันขึ้นปีใหม่_ลงวันที่_24_ธันวาคม_2483)
+        * [National Children's Day](https://web.archive.org/web/20230929070232/https://thainews.prd.go.th/banner/th/children'sday/)
+        * [Chakri Memorial Day](https://web.archive.org/web/20221003075521/https://www.ocac.go.th/news/๖-เมษายน-วันจักรี/v)
         * Songkran Festival:
-            * [museumsiam.org](http://tiny.cc/wa_museumsiam_songkran)
-            * <https://resolution.soc.go.th/?prep_id=123659>
-        * [National Labour Day](https://www.thairath.co.th/lifestyle/culture/1832869)
-        * [National Day (24 June: Defunct)](http://tiny.cc/wa_mincul_nat_day)
+            * [museumsiam.org](https://web.archive.org/web/20230205074402/https://m.museumsiam.org/da-detail2.php?MID=3&CID=177&CONID=4033)
+            * <https://web.archive.org/web/20250501040114/https://resolution.soc.go.th/?prep_id=123659>
+        * [National Labour Day](https://web.archive.org/web/20220629085454/https://www.thairath.co.th/lifestyle/culture/1832869)
+        * [National Day (24 June: Defunct)](https://web.archive.org/web/20091106202525/http://www.culture.go.th/study.php?&YY=2548&MM=11&DD=2)
         * Coronation Day:
-            * <https://www.matichon.co.th/politics/news_526200>
-            * <https://workpointtoday.com/news1-5/>
-        * [HM Queen Suthida's Birthday](https://www.thairath.co.th/news/politic/1567418)
-        * [HM Maha Vajiralongkorn's Birthday](https://www.matichon.co.th/politics/news_526200)
-        * [HM Queen Sirikit the Queen Mother's Birthday](https://hilight.kapook.com/view/14164)
-        * [National Mother's Day](https://www.brh.go.th/index.php/2019-02-27-04-11-52/542-12-2564)
-        * [HM King Bhumibol Adulyadej Memorial Day](https://www.matichon.co.th/politics/news_526200)
+            * <https://web.archive.org/web/20220817223130/https://www.matichon.co.th/politics/news_526200>
+            * <https://web.archive.org/web/20230205075326/https://workpointtoday.com/news1-5/>
+        * [HM Queen Suthida's Birthday](https://web.archive.org/web/20241217104142/https://www.thairath.co.th/news/politic/1567418)
+        * [HM Maha Vajiralongkorn's Birthday](https://web.archive.org/web/20220817223130/https://www.matichon.co.th/politics/news_526200)
+        * [HM Queen Sirikit the Queen Mother's Birthday](https://web.archive.org/web/20250203002257/https://hilight.kapook.com/view/14164)
+        * [National Mother's Day](https://web.archive.org/web/20221207161434/https://www.brh.go.th/index.php/2019-02-27-04-11-52/542-12-2564)
+        * [HM King Bhumibol Adulyadej Memorial Day](https://web.archive.org/web/20220817223130/https://www.matichon.co.th/politics/news_526200)
         * HM King Chulalongkorn Memorial Day:
             * <https://th.wikipedia.org/wiki/วันปิยมหาราช>
-            * <https://www.sanook.com/news/9072518/>
+            * <https://web.archive.org/web/20231024220855/https://www.sanook.com/news/9072518/>
         * HM King Bhumibol Adulyadej's Birthday
-            * [Ministry of Culture](http://tiny.cc/wa_mincul_nat_day)
-            * <https://hilight.kapook.com/view/148862>
-        * [National Father's Day](https://www.brh.go.th/index.php/2019-02-27-04-12-21/594-5-5)
+            * [Ministry of Culture](https://web.archive.org/web/20091106202525/http://www.culture.go.th/study.php?&YY=2548&MM=11&DD=2)
+            * <https://web.archive.org/web/20250126073943/https://hilight.kapook.com/view/148862>
+        * [National Father's Day](https://web.archive.org/web/20230205075650/https://www.brh.go.th/index.php/2019-02-27-04-12-21/594-5-5)
         * Constitution Day:
-            * [ประเทศไทย](https://th.wikipedia.org/wiki/วันรัฐธรรมนูญ_)
-            * <https://hilight.kapook.com/view/18208>
-            * [Bank of Thailand](http://tiny.cc/wa_bot_1992)
-            * <https://www.myhora.com/ปฏิทิน/ปฏิทิน-พ.ศ.2475.aspx>
+            * <https://th.wikipedia.org/wiki/วันรัฐธรรมนูญ>
+            * <https://web.archive.org/web/20250212210436/https://hilight.kapook.com/view/18208>
+            * [Bank of Thailand](https://web.archive.org/web/20230205072056/https://www.bot.or.th/Thai/FinancialInstitutions/FIholiday/Pages/2023.aspx)
+            * <https://web.archive.org/web/20161028001043/http://www.myhora.com:80/ปฏิทิน/ปฏิทิน-พ.ศ.2475.aspx>
         * New Year's Eve:
-            * [Bank of Thailand](http://tiny.cc/wa_bot_1992)
-            * <https://resolution.soc.go.th/?prep_id=205799>
-            * <https://resolution.soc.go.th/?prep_id=210744>
-        * [Makha Bucha](https://www.onab.go.th/th/content/category/detail/id/73/iid/3403)
-        * [Visakha Bucha](https://www.onab.go.th/th/content/category/detail/id/73/iid/3401)
-        * [Asarnha Bucha](https://www.onab.go.th/th/content/category/detail/id/73/iid/3397)
-        * [Buddhist Lent Day](https://www.onab.go.th/th/content/category/detail/id/73/iid/3395)
+            * [Bank of Thailand](https://web.archive.org/web/20230205072056/https://www.bot.or.th/Thai/FinancialInstitutions/FIholiday/Pages/2023.aspx)
+            * <https://web.archive.org/web/20250428140227/https://resolution.soc.go.th/?prep_id=205799>
+            * <https://web.archive.org/web/20250428152003/https://resolution.soc.go.th/?prep_id=210744>
+        * [Makha Bucha](https://web.archive.org/web/20240908185818/https://www.onab.go.th/th/content/category/detail/id/73/iid/3403)
+        * [Visakha Bucha](https://web.archive.org/web/20240908190019/https://www.onab.go.th/th/content/category/detail/id/73/iid/3401)
+        * [Asarnha Bucha](https://web.archive.org/web/20240816131909/https://www.onab.go.th/th/content/category/detail/id/73/iid/3397)
+        * [Buddhist Lent Day](https://web.archive.org/web/20240908185432/https://www.onab.go.th/th/content/category/detail/id/73/iid/3395)
         * Royal Ploughing Ceremony:
             * <https://en.wikipedia.org/wiki/Royal_Ploughing_Ceremony>
-            * <https://www.lib.ru.ac.th/journal/may/may_phauchmongkol.html>
-            * <https://dl.parliament.go.th/handle/20.500.13072/103428>
-            * <https://dl.parliament.go.th/handle/20.500.13072/92816>
-            * <https://e-manage.mju.ac.th/timeline_detail.aspx?key=MTk4>
-            * <https://resolution.soc.go.th/PDF_UPLOAD/2510/932141.pdf>
-            * <https://www.myhora.com/ปฏิทิน/วันพืชมงคล.aspx>
+            * <https://web.archive.org/web/20241211020149/https://www.lib.ru.ac.th/journal/may/may_phauchmongkol.html>
+            * <https://web.archive.org/web/20250427185801/https://dl.parliament.go.th/handle/20.500.13072/103428>
+            * <https://web.archive.org/web/20250427185656/https://dl.parliament.go.th/handle/20.500.13072/92816>
+            * <https://web.archive.org/web/20250428135456/http://mdc.library.mju.ac.th/article/57695/297565/367757.pdf>
+            * <https://web.archive.org/web/20250428140422/https://resolution.soc.go.th/PDF_UPLOAD/2510/932141.pdf>
+            * <https://web.archive.org/web/20161028001043/http://www.myhora.com:80/ปฏิทิน/ปฏิทิน-พ.ศ.2475.aspx>
         * [Royal Thai Armed Forces Day](https://th.wikipedia.org/wiki/วันกองทัพไทย)
-        * [Teacher's Day](https://www.cabinet.soc.go.th/doc_image/2500/718941.pdf)
+        * [Teacher's Day](https://web.archive.org/web/20250117105542/http://event.sanook.com/day/teacher-day/)
 
     !!! info "Info"
         If Public Holiday falls on weekends, (in lieu) on workday.
@@ -181,13 +181,13 @@ class Thailand(ObservedHolidayBase, InternationalHolidays, StaticHolidays, ThaiC
     """
 
     country = "TH"
-    supported_categories = (ARMED_FORCES, BANK, GOVERNMENT, PUBLIC, SCHOOL, WORKDAY)
     default_language = "th"
     # %s (in lieu).
     observed_label = tr("ชดเชย%s")
-    supported_languages = ("en_US", "th")
     # First Holiday Decree was promulgated in March 1914.
     start_year = 1914
+    supported_categories = (ARMED_FORCES, BANK, GOVERNMENT, PUBLIC, SCHOOL, WORKDAY)
+    supported_languages = ("en_US", "th", "uk")
 
     def __init__(self, *args, **kwargs):
         InternationalHolidays.__init__(self)
@@ -932,7 +932,7 @@ class Thailand(ObservedHolidayBase, InternationalHolidays, StaticHolidays, ThaiC
             # Status: In-Use.
             # Started in 1990.
 
-            # HM King Ramkamhaeng Memorial Day.
+            # HM King Ramkhamhaeng Memorial Day.
             self._add_holiday_jan_17(tr("วันพ่อขุนรามคำแหงมหาราช"))
 
         if self._year >= 1995:
@@ -972,7 +972,7 @@ class ThailandStaticHolidays:
     วันหยุดพิเศษ (เพิ่มเติม) - see Bank of Thailand's DB for Cross-Check.
 
     Special Bank Holidays Pre-1992:
-       * [HM Queen Rambai Barni's Royal Cremation Ceremony](https://ratchakitcha.soc.go.th/documents/1560949.pdf)
+       * [HM Queen Rambai Barni's Royal Cremation Ceremony](https://web.archive.org/web/20250428140115/https://ratchakitcha.soc.go.th/documents/1560949.pdf)
     """
 
     # Special In Lieu Holiday.
