@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -14,8 +14,9 @@ from datetime import date
 
 from dateutil.easter import EASTER_ORTHODOX, EASTER_WESTERN, easter
 
-from holidays.calendars.gregorian import GREGORIAN_CALENDAR, JAN, DEC, _timedelta
-from holidays.calendars.julian import JULIAN_CALENDAR
+from holidays.calendars.ethiopian import ETHIOPIAN_CALENDAR, is_ethiopian_leap_year
+from holidays.calendars.gregorian import GREGORIAN_CALENDAR, JAN, AUG, SEP, DEC, _timedelta
+from holidays.calendars.julian import JULIAN_CALENDAR, julian_calendar_drift
 from holidays.calendars.julian_revised import JULIAN_REVISED_CALENDAR
 
 
@@ -36,8 +37,8 @@ class ChristianHolidays:
         self.__verify_calendar(calendar)
 
         return (
-            date(self._year, JAN, 7)
-            if self.__is_julian_calendar(calendar)
+            _timedelta(date(self._year, JAN, 7), julian_calendar_drift(self._year - 1))
+            if self.__is_julian_calendar(calendar) or self.__is_ethiopian_calendar(calendar)
             else date(self._year, DEC, 25)
         )
 
@@ -53,6 +54,14 @@ class ChristianHolidays:
             method=EASTER_WESTERN if self.__is_gregorian_calendar(calendar) else EASTER_ORTHODOX,
         )
 
+    @staticmethod
+    def __is_ethiopian_calendar(calendar):
+        """
+        Return True if `calendar` is Ethiopian calendar.
+        Return False otherwise.
+        """
+        return calendar == ETHIOPIAN_CALENDAR
+
     @staticmethod
     def __is_gregorian_calendar(calendar):
         """
@@ -74,10 +83,15 @@ class ChristianHolidays:
         """
         Verify calendar type.
         """
-        if calendar not in {GREGORIAN_CALENDAR, JULIAN_CALENDAR, JULIAN_REVISED_CALENDAR}:
+        if calendar not in {
+            ETHIOPIAN_CALENDAR,
+            GREGORIAN_CALENDAR,
+            JULIAN_CALENDAR,
+            JULIAN_REVISED_CALENDAR,
+        }:
             raise ValueError(
-                f"Unknown calendar name: {calendar}. "
-                f"Use `{GREGORIAN_CALENDAR}`, `{JULIAN_CALENDAR}` or `{JULIAN_REVISED_CALENDAR}`."
+                f"Unknown calendar name: {calendar}. Use `{ETHIOPIAN_CALENDAR}`, "
+                f"`{GREGORIAN_CALENDAR}`, `{JULIAN_CALENDAR}` or `{JULIAN_REVISED_CALENDAR}`."
             )
 
     @property
@@ -100,7 +114,7 @@ class ChristianHolidays:
 
         Also known as All Hallows' Day, the Feast of All Saints,
         the Feast of All Hallows, the Solemnity of All Saints, and Hallowmas.
-        https://en.wikipedia.org/wiki/All_Saints%27_Day
+        https://en.wikipedia.org/wiki/All_Saints'_Day
         """
         return self._add_holiday_nov_1(name)
 
@@ -111,12 +125,12 @@ class ChristianHolidays:
         All Souls' Day is a day of prayer and remembrance for the faithful
         departed, observed by certain Christian denominations on 2 November.
         In Belarussian tradition it is called Dziady.
-        https://en.wikipedia.org/wiki/All_Souls%27_Day
+        https://en.wikipedia.org/wiki/All_Souls'_Day
         https://en.wikipedia.org/wiki/Dziady
         """
         return self._add_holiday_nov_2(name)
 
-    def _add_ascension_thursday(self, name) -> date:
+    def _add_ascension_thursday(self, name, calendar=None) -> date:
         """
         Add Ascension Thursday (39 days after the Easter Sunday).
 
@@ -124,7 +138,7 @@ class ChristianHolidays:
         Day, or sometimes Holy Thursday.
         https://en.wikipedia.org/wiki/Feast_of_the_Ascension
         """
-        return self._add_holiday(name, _timedelta(self._easter_sunday, +39))
+        return self._add_holiday(name, _timedelta(self.__get_easter_sunday(calendar), +39))
 
     def _add_ash_monday(self, name) -> date:
         """
@@ -158,7 +172,9 @@ class ChristianHolidays:
         self.__verify_calendar(calendar)
 
         return (
-            self._add_holiday_aug_28(name)
+            self._add_holiday(
+                name, _timedelta(date(self._year, AUG, 28), julian_calendar_drift(self._year))
+            )
             if self.__is_julian_calendar(calendar)
             else self._add_holiday_aug_15(name)
         )
@@ -197,7 +213,7 @@ class ChristianHolidays:
 
     def _add_carnival_tuesday(self, name) -> date:
         """
-        Add Carnival Monday (47 days before Easter Sunday).
+        Add Carnival Tuesday (47 days before Easter Sunday).
 
         Carnival is a Catholic Christian festive season that occurs before
         the liturgical season of Lent.
@@ -299,10 +315,30 @@ class ChristianHolidays:
         calendar = calendar or self.__calendar
         self.__verify_calendar(calendar)
 
-        return (
-            self._add_holiday_jan_19(name)
-            if self.__is_julian_calendar(calendar)
-            else self._add_holiday_jan_6(name)
+        if self.__is_julian_calendar(calendar) or self.__is_ethiopian_calendar(calendar):
+            dt = _timedelta(date(self._year, JAN, 19), julian_calendar_drift(self._year - 1))
+            return self._add_holiday(
+                name,
+                _timedelta(dt, +1)
+                if self.__is_ethiopian_calendar(calendar)
+                and is_ethiopian_leap_year(self._year - 1)
+                else dt,
+            )
+        else:
+            return self._add_holiday_jan_6(name)
+
+    def _add_finding_of_true_cross(self, name) -> date:
+        """
+        Add Finding of True Cross.
+
+        Finding of True Cross, also known as Meskel, is an Ethiopian and Eritrean Orthodox
+        Tewahedo Church holiday that commemorates the discovery of the True Cross by the
+        Roman Empress Saint Helena of Constantinople in the fourth century.
+        https://en.wikipedia.org/wiki/Meskel
+        """
+        dt = _timedelta(date(self._year, SEP, 27), julian_calendar_drift(self._year))
+        return self._add_holiday(
+            name, _timedelta(dt, +1) if is_ethiopian_leap_year(self._year) else dt
         )
 
     def _add_good_friday(self, name, calendar=None) -> date:
@@ -316,16 +352,16 @@ class ChristianHolidays:
         """
         return self._add_holiday(name, _timedelta(self.__get_easter_sunday(calendar), -2))
 
-    def _add_holy_saturday(self, name) -> date:
+    def _add_holy_saturday(self, name, calendar=None) -> date:
         """
         Add Holy Saturday (1 day before Easter Sunday).
 
         Great and Holy Saturday is a day between Good Friday and Easter Sunday.
         https://en.wikipedia.org/wiki/Holy_Saturday
         """
-        return self._add_holiday(name, _timedelta(self._easter_sunday, -1))
+        return self._add_holiday(name, _timedelta(self.__get_easter_sunday(calendar), -1))
 
-    def _add_holy_thursday(self, name) -> date:
+    def _add_holy_thursday(self, name, calendar=None) -> date:
         """
         Add Holy Thursday (3 days before Easter Sunday).
 
@@ -334,7 +370,7 @@ class ChristianHolidays:
         Jesus Christ with the Apostles, as described in the canonical gospels.
         https://en.wikipedia.org/wiki/Maundy_Thursday
         """
-        return self._add_holiday(name, _timedelta(self._easter_sunday, -3))
+        return self._add_holiday(name, _timedelta(self.__get_easter_sunday(calendar), -3))
 
     def _add_immaculate_conception_day(self, name) -> date:
         """
@@ -355,7 +391,7 @@ class ChristianHolidays:
         """
         return self._add_holiday_sep_8(name)
 
-    def _add_palm_sunday(self, name) -> date:
+    def _add_palm_sunday(self, name, calendar=None) -> date:
         """
         Add Palm Sunday (7 days before Easter Sunday).
 
@@ -365,7 +401,7 @@ class ChristianHolidays:
         Palm Sunday marks the first day of Holy Week.
         https://en.wikipedia.org/wiki/Palm_Sunday
         """
-        return self._add_holiday(name, _timedelta(self._easter_sunday, -7))
+        return self._add_holiday(name, _timedelta(self.__get_easter_sunday(calendar), -7))
 
     def _add_rejoicing_day(self, name) -> date:
         """
@@ -373,7 +409,7 @@ class ChristianHolidays:
 
         Add Day Of Rejoicing ("Radonitsa"), in the Russian Orthodox Church is
         a commemoration of the departed observed on the second Tuesday of
-        Pascha (Easter).In Ukrainian tradition it is called Provody.
+        Pascha (Easter). In Ukrainian tradition it is called Provody.
         https://en.wikipedia.org/wiki/Radonitsa
         """
         return self._add_holiday(name, _timedelta(self._easter_sunday, +9))
@@ -384,7 +420,7 @@ class ChristianHolidays:
 
         Saint George's Day is celebrated on 23 April, the traditionally
         accepted date of the saint's death.
-        https://en.wikipedia.org/wiki/Saint_George%27s_Day
+        https://en.wikipedia.org/wiki/Saint_George's_Day
         """
         return self._add_holiday_apr_23(name)
 
@@ -415,13 +451,13 @@ class ChristianHolidays:
         Solemnity of Saint Joseph, is in Western Christianity the principal
         feast day of Saint Joseph, husband of the Virgin Mary and legal father
         of Jesus Christ.
-        https://en.wikipedia.org/wiki/Saint_Joseph%27s_Day
+        https://en.wikipedia.org/wiki/Saint_Joseph's_Day
         """
         return self._add_holiday_mar_19(name)
 
     def _add_saints_peter_and_paul_day(self, name) -> date:
         """
-        Feast of Saints Peter and Paul (June 29th).
+        Add Feast of Saints Peter and Paul (June 29th).
 
         A liturgical feast in honor of the martyrdom in Rome of the apostles
         Saint Peter and Saint Paul, which is observed on 29 June.
@@ -440,7 +476,7 @@ class ChristianHolidays:
         """
         return self._add_holiday(name, _timedelta(self._easter_sunday, +50))
 
-    def _add_whit_sunday(self, name) -> date:
+    def _add_whit_sunday(self, name, calendar=None) -> date:
         """
         Add Whit Sunday (49 days after Easter Sunday).
 
@@ -450,7 +486,7 @@ class ChristianHolidays:
         Feast of Weeks.
         https://en.wikipedia.org/wiki/Pentecost
         """
-        return self._add_holiday(name, _timedelta(self._easter_sunday, +49))
+        return self._add_holiday(name, _timedelta(self.__get_easter_sunday(calendar), +49))
 
     def _add_trinity_sunday(self, name) -> date:
         """
