@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -27,11 +27,11 @@ class HebrewCalendarHolidays:
         self._hebrew_calendar = _HebrewLunisolar()
 
     def _add_hebrew_calendar_holiday(
-        self, name: str, hol_date: date, days_delta: Union[int, Iterable[int]] = 0
+        self, name: str, holiday_date: date, days_delta: Union[int, Iterable[int]] = 0
     ) -> set[date]:
         added_dates = set()
         for delta in (days_delta,) if isinstance(days_delta, int) else days_delta:
-            if dt := self._add_holiday(name, _timedelta(hol_date, delta)):
+            if dt := self._add_holiday(name, _timedelta(holiday_date, delta)):
                 added_dates.add(dt)
         return added_dates
 
