@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -182,16 +182,6 @@ class IslamicHolidays(EasternCalendarHolidays):
             name, self._islamic_calendar.eid_al_fitr_dates(self._year), days_delta=+2
         )
 
-    def _add_eid_al_fitr_day_four(self, name) -> set[date]:
-        """
-        Add Eid al-Fitr Day Four.
-
-        https://en.wikipedia.org/wiki/Eid_al-Fitr
-        """
-        return self._add_islamic_calendar_holiday(
-            name, self._islamic_calendar.eid_al_fitr_dates(self._year), days_delta=+3
-        )
-
     def _add_eid_al_fitr_eve(self, name) -> set[date]:
         """
         Add Eid al-Fitr Eve (last day of 9th month of Islamic calendar).
@@ -222,11 +212,21 @@ class IslamicHolidays(EasternCalendarHolidays):
             name, self._islamic_calendar.fatima_death_dates(self._year)
         )
 
+    def _add_grand_magal_of_touba(self, name) -> set[date]:
+        """
+        Annual religious pilgrimage of Senegalese Mouride brotherhood.
+
+        https://en.wikipedia.org/wiki/Grand_Magal_of_Touba
+        """
+        return self._add_islamic_calendar_holiday(
+            name, self._islamic_calendar.grand_magal_of_touba_dates(self._year)
+        )
+
     def _add_hari_hol_johor(self, name) -> set[date]:
         """
         Hari Hol Johor.
 
-        https://publicholidays.com.my/hari-hol-almarhum-sultan-iskandar/
+        https://web.archive.org/web/20241202170507/https://publicholidays.com.my/hari-hol-almarhum-sultan-iskandar/
         """
         return self._add_islamic_calendar_holiday(
             name, self._islamic_calendar.hari_hol_johor_dates(self._year)
@@ -246,7 +246,7 @@ class IslamicHolidays(EasternCalendarHolidays):
         """
         Add 29th Ramadan holiday.
 
-        https://decree.om/2022/rd20220088/
+        https://web.archive.org/web/20250323065556/https://decree.om/2022/rd20220088/
         """
         return self._add_islamic_calendar_holiday(
             name, self._islamic_calendar.ramadan_beginning_dates(self._year), days_delta=+28
@@ -299,7 +299,7 @@ class IslamicHolidays(EasternCalendarHolidays):
         Add Isra' and Mi'raj Day (27th day of 7th month).
 
         The Prophet's Ascension.
-        https://en.wikipedia.org/wiki/Isra%27_and_Mi%27raj
+        https://en.wikipedia.org/wiki/Isra'_and_Mi'raj
         """
         return self._add_islamic_calendar_holiday(
             name, self._islamic_calendar.isra_and_miraj_dates(self._year)
@@ -357,12 +357,29 @@ class IslamicHolidays(EasternCalendarHolidays):
         Nuzul Al Quran is a Muslim festival to remember the day when Prophet
         Muhammad received his first revelation of Islam's sacred book,
         the holy Quran.
-        https://zamzam.com/blog/nuzul-al-quran/
+        https://web.archive.org/web/20241012115752/https://zamzam.com/blog/nuzul-al-quran/
         """
         return self._add_islamic_calendar_holiday(
             name, self._islamic_calendar.nuzul_al_quran_dates(self._year)
         )
 
+    def _add_prophet_baptism_day(self, name) -> set[date]:
+        """
+        Add Prophet's Baptism.
+
+        Celebrated one week after the Prophet Mohammed's Birthday, this
+        marks the traditional Islamic birth rites that take place seven
+        days after birth. While it is not recognized in mainstream Islam,
+        Mali celebrates it as a cultural-religious public holiday that
+        reflects the local interpretation and honor of the Prophet Muhammad.
+        The term "baptism" is symbolic and not literal - there's no Islamic
+        ritual akin to Christian baptism.
+        https://web.archive.org/web/20240722052111/https://www.officeholidays.com/holidays/mali/prophets-baptism
+        """
+        return self._add_islamic_calendar_holiday(
+            name, self._islamic_calendar.mawlid_dates(self._year), days_delta=+7
+        )
+
     def _add_prophet_death_day(self, name) -> set[date]:
         """
         Add death of Prophet Muhammad and Hasan ibn Ali day (28th day of 2nd month).
@@ -399,7 +416,7 @@ class IslamicHolidays(EasternCalendarHolidays):
         """
         Add birthday of Prophet Muhammad and Ja'far al-Sadiq day (17th day of 3rd month).
 
-        https://en.wikipedia.org/wiki/Ja%27far_al-Sadiq
+        https://en.wikipedia.org/wiki/Ja'far_al-Sadiq
         """
         return self._add_islamic_calendar_holiday(
             name, self._islamic_calendar.sadiq_birthday_dates(self._year)
@@ -409,7 +426,7 @@ class IslamicHolidays(EasternCalendarHolidays):
         """
         Add death of Ja'far al-Sadiq day (25th day of 10th month).
 
-        https://en.wikipedia.org/wiki/Ja%27far_al-Sadiq
+        https://en.wikipedia.org/wiki/Ja'far_al-Sadiq
         """
         return self._add_islamic_calendar_holiday(
             name, self._islamic_calendar.sadiq_death_dates(self._year)
