@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -186,6 +186,7 @@ class TestIndonesia(CommonCountryTests, TestCase):
             "2025-05-13",
             "2025-05-30",
             "2025-06-09",
+            "2025-08-18",
             "2025-12-26",
         )
         dt_observed = ("2020-12-31",)
