@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -30,33 +30,33 @@ class TestKuwait(CommonCountryTests, TestCase):
             ("2022-01-01", "رأس السنة الميلادية"),
             ("2022-02-25", "اليوم الوطني"),
             ("2022-02-26", "يوم التحرير"),
-            ("2022-02-28", "(تقدير) ليلة المعراج"),
-            ("2022-05-02", "(تقدير) عيد الفطر"),
-            ("2022-05-03", "(تقدير) عطلة عيد الفطر"),
-            ("2022-05-04", "(تقدير) عطلة عيد الفطر"),
-            ("2022-07-08", "(تقدير) يوم عرفة"),
-            ("2022-07-09", "(تقدير) عيد الأضحى"),
-            ("2022-07-10", "(تقدير) عطلة عيد الأضحى"),
-            ("2022-07-11", "(تقدير) عطلة عيد الأضحى"),
-            ("2022-07-30", "(تقدير) رأس السنة الهجرية"),
-            ("2022-10-08", "(تقدير) عيد المولد النبوي"),
+            ("2022-02-28", "ليلة المعراج (المقدرة)"),
+            ("2022-05-02", "عيد الفطر (المقدرة)"),
+            ("2022-05-03", "عطلة عيد الفطر (المقدرة)"),
+            ("2022-05-04", "عطلة عيد الفطر (المقدرة)"),
+            ("2022-07-08", "يوم عرفة (المقدرة)"),
+            ("2022-07-09", "عيد الأضحى (المقدرة)"),
+            ("2022-07-10", "عطلة عيد الأضحى (المقدرة)"),
+            ("2022-07-11", "عطلة عيد الأضحى (المقدرة)"),
+            ("2022-07-30", "رأس السنة الهجرية (المقدرة)"),
+            ("2022-10-08", "عيد المولد النبوي (المقدرة)"),
         )
 
     def test_l10n_default(self):
         self.assertLocalizedHolidays(
             ("2023-01-01", "رأس السنة الميلادية"),
-            ("2023-02-18", "(تقدير) ليلة المعراج"),
+            ("2023-02-18", "ليلة المعراج (المقدرة)"),
             ("2023-02-25", "اليوم الوطني"),
             ("2023-02-26", "يوم التحرير"),
-            ("2023-04-21", "(تقدير) عيد الفطر"),
-            ("2023-04-22", "(تقدير) عطلة عيد الفطر"),
-            ("2023-04-23", "(تقدير) عطلة عيد الفطر"),
-            ("2023-06-27", "(تقدير) يوم عرفة"),
-            ("2023-06-28", "(تقدير) عيد الأضحى"),
-            ("2023-06-29", "(تقدير) عطلة عيد الأضحى"),
-            ("2023-06-30", "(تقدير) عطلة عيد الأضحى"),
-            ("2023-07-19", "(تقدير) رأس السنة الهجرية"),
-            ("2023-09-27", "(تقدير) عيد المولد النبوي"),
+            ("2023-04-21", "عيد الفطر (المقدرة)"),
+            ("2023-04-22", "عطلة عيد الفطر (المقدرة)"),
+            ("2023-04-23", "عطلة عيد الفطر (المقدرة)"),
+            ("2023-06-27", "يوم عرفة (المقدرة)"),
+            ("2023-06-28", "عيد الأضحى (المقدرة)"),
+            ("2023-06-29", "عطلة عيد الأضحى (المقدرة)"),
+            ("2023-06-30", "عطلة عيد الأضحى (المقدرة)"),
+            ("2023-07-19", "رأس السنة الهجرية (المقدرة)"),
+            ("2023-09-27", "عيد المولد النبوي (المقدرة)"),
         )
 
     def test_l10n_en_us(self):
