@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -95,9 +95,9 @@ class TestMalaysia(CommonCountryTests, TestCase):
         )
 
         for col, subdiv in enumerate(Malaysia.subdivisions):
-            state_holidays = self.subdiv_holidays[subdiv]
+            subdiv_holidays = self.subdiv_holidays[subdiv]
             for dt, is_holiday in rows:
-                self.assertEqual(dt in state_holidays, is_holiday[col])
+                self.assertEqual(dt in subdiv_holidays, is_holiday[col])
 
     def test_special_holidays(self):
         self.assertHoliday(
