@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -13,10 +13,10 @@
 from unittest import TestCase
 
 from holidays.countries.russia import Russia, RU, RUS
-from tests.common import CommonCountryTests
+from tests.common import CommonCountryTests, WorkingDayTests
 
 
-class TestRussia(CommonCountryTests, TestCase):
+class TestRussia(CommonCountryTests, WorkingDayTests, TestCase):
     @classmethod
     def setUpClass(cls):
         super().setUpClass(Russia, years=range(1991, 2025))
@@ -27,9 +27,8 @@ class TestRussia(CommonCountryTests, TestCase):
     def test_no_holidays(self):
         self.assertNoHolidays(Russia(years=1990))
 
-    def test_special_holidays(self):
+    def test_substituted_holidays(self):
         self.assertHoliday(
-            # Substituted Holidays.
             "1991-05-03",
             "1991-05-10",
             "1994-03-07",
@@ -210,6 +209,99 @@ class TestRussia(CommonCountryTests, TestCase):
             "2023-11-06",
         )
 
+    def test_workdays(self):
+        self.assertWorkingDay(
+            "1991-05-05",
+            "1991-05-12",
+            "1994-03-05",
+            "1995-05-06",
+            "1995-11-04",
+            "1995-12-09",
+            "1996-05-05",
+            "1996-05-12",
+            "1996-11-10",
+            "1996-12-14",
+            "1996-12-15",
+            "1997-01-05",
+            "1997-06-15",
+            "1999-01-10",
+            "2000-05-06",
+            "2000-11-04",
+            "2000-12-09",
+            "2001-03-11",
+            "2001-04-28",
+            "2001-06-09",
+            "2001-12-29",
+            "2002-04-27",
+            "2002-05-18",
+            "2002-11-10",
+            "2002-12-15",
+            "2003-01-04",
+            "2003-01-05",
+            "2003-06-21",
+            "2005-03-05",
+            "2005-05-14",
+            "2006-02-26",
+            "2006-05-06",
+            "2007-04-28",
+            "2007-06-09",
+            "2007-12-29",
+            "2008-05-04",
+            "2008-06-07",
+            "2008-11-01",
+            "2009-01-11",
+            "2010-02-27",
+            "2010-11-13",
+            "2011-03-05",
+            "2012-03-11",
+            "2012-04-28",
+            "2012-05-05",
+            "2012-05-12",
+            "2012-06-09",
+            "2012-12-29",
+            "2013-01-05",
+            "2013-01-06",
+            # "2013-02-25",
+            "2014-01-04",
+            "2014-01-05",
+            # "2014-02-24",
+            "2015-01-03",
+            "2015-01-04",
+            "2016-01-02",
+            "2016-01-03",
+            "2016-02-20",
+            "2017-01-01",
+            "2017-01-07",
+            "2018-01-06",
+            "2018-01-07",
+            "2018-04-28",
+            "2018-06-09",
+            "2018-12-29",
+            "2019-01-05",
+            "2019-01-06",
+            "2019-02-23",
+            "2020-01-04",
+            "2020-01-05",
+            "2021-01-02",
+            "2021-01-03",
+            "2021-02-20",
+            "2022-01-01",
+            "2022-01-02",
+            "2022-03-05",
+            "2023-01-01",
+            "2023-01-08",
+            "2024-01-06",
+            "2024-01-07",
+            "2024-04-27",
+            "2024-11-02",
+            "2024-12-28",
+            "2025-01-04",
+            "2025-01-05",
+            "2025-02-23",
+            "2025-03-08",
+            "2025-11-01",
+        )
+
     def test_new_year(self):
         name_1 = "Новый год"
         name_2 = "Новогодние каникулы"
