@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -23,17 +23,18 @@ class TestSpain(CommonCountryTests, TestCase):
     def setUpClass(cls):
         super().setUpClass(Spain)
 
-    def _assertVariableDays(self, year: int, subdiv_holidays: dict):  # noqa: N802
-        observed_prov_holidays = {
+    def _assertVariableDays(self, year: int, expected_subdiv_holidays: dict):  # noqa: N802
+        observed_subdiv_holidays = {
             subdiv: Spain(subdiv=subdiv, years=year) for subdiv in Spain.subdivisions
         }
-        for hol_date, hol_provs in subdiv_holidays.items():
-            dt = date(year, *hol_date)
-            for subdiv, prov_holidays in observed_prov_holidays.items():
+        for month_day, subdivisions in expected_subdiv_holidays.items():
+            dt = date(year, *month_day)
+            for subdiv, observed_holidays in observed_subdiv_holidays.items():
                 self.assertEqual(
-                    dt in prov_holidays,
-                    subdiv in hol_provs,
-                    f"Failed date `{dt:%Y-%m-%d}`, province `{subdiv}`: {', '.join(hol_provs)}",
+                    dt in observed_holidays,
+                    subdiv in subdivisions,
+                    f"Failed date `{dt:%Y-%m-%d}`, subdiv `{subdiv}`: "
+                    f"{', '.join(sorted(subdivisions))}",
                 )
 
     def test_country_aliases(self):
