@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -859,7 +859,7 @@ class TestThailand(CommonCountryTests, TestCase):
             ("2022-01-13", "National Aviation Day"),
             ("2022-01-14", "National Forest Conservation Day"),
             ("2022-01-16", "Teacher's Day"),
-            ("2022-01-17", "HM King Ramkamhaeng Memorial Day"),
+            ("2022-01-17", "HM King Ramkhamhaeng Memorial Day"),
             ("2022-01-18", "Royal Thai Armed Forces Day"),
             ("2022-02-03", "Thai Veterans Day"),
             ("2022-02-16", "Makha Bucha"),
@@ -904,3 +904,56 @@ class TestThailand(CommonCountryTests, TestCase):
             ("2022-12-30", "Bridge Public Holiday"),
             ("2022-12-31", "New Year's Eve"),
         )
+
+    def test_l10n_uk(self):
+        self.assertLocalizedHolidays(
+            "uk",
+            ("2022-01-01", "Новий рік"),
+            ("2022-01-03", "Новий рік (вихідний)"),
+            ("2022-01-08", "Національний день дітей"),
+            ("2022-01-13", "Національний день авіації"),
+            ("2022-01-14", "Національний день охорони лісів"),
+            ("2022-01-16", "День вчителя"),
+            ("2022-01-17", "День памʼяті короля Рамкхамхенга"),
+            ("2022-01-18", "День Королівських збройних сил Таїланду"),
+            ("2022-02-03", "День ветеранів"),
+            ("2022-02-16", "Маха Буча"),
+            ("2022-02-26", "Національний день художника"),
+            ("2022-03-08", "Міжнародний жіночий день"),
+            ("2022-04-06", "День памʼяті короля Рами I та династії Чакрі"),
+            ("2022-04-13", "Тайський Новий рік"),
+            ("2022-04-14", "Тайський Новий рік"),
+            ("2022-04-15", "Тайський Новий рік"),
+            ("2022-05-01", "Національний день праці"),
+            ("2022-05-02", "Національний день праці (вихідний)"),
+            ("2022-05-04", "День коронації"),
+            ("2022-05-13", "Церемонія королівської оранки"),
+            ("2022-05-15", "Вісака Буча"),
+            ("2022-05-16", "Вісака Буча (вихідний)"),
+            ("2022-06-03", "День народження Її Величності королеви Сутіди"),
+            ("2022-07-13", "Асарна Буча"),
+            ("2022-07-14", "Початок буддистського посту"),
+            ("2022-07-15", "Проміжний вихідний"),
+            ("2022-07-28", "День народження Його Величності короля Маха Вачіралонгкорна"),
+            ("2022-07-29", "Проміжний вихідний"),
+            (
+                "2022-08-12",
+                "День народження Її Величності королеви-матері Сірікіт; Національний день матері",
+            ),
+            ("2022-08-18", "Національний день науки"),
+            ("2022-09-28", "День національного прапора Таїланду"),
+            ("2022-10-13", "Річниця смерті Його Величності короля Пуміпона Адульядета Великого"),
+            ("2022-10-14", "Проміжний вихідний"),
+            ("2022-10-23", "День памʼяті Його Величності короля Чулалонгкорна"),
+            ("2022-10-24", "День памʼяті Його Величності короля Чулалонгкорна (вихідний)"),
+            ("2022-11-08", "Лой Кратонг"),
+            (
+                "2022-12-05",
+                "Національний день; Національний день батька; "
+                "Річниця дня народження Його Величності короля Пуміпона Адульядета Великого",
+            ),
+            ("2022-12-10", "День Конституції"),
+            ("2022-12-12", "День Конституції (вихідний)"),
+            ("2022-12-30", "Проміжний вихідний"),
+            ("2022-12-31", "Переддень Нового року"),
+        )
