@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -72,18 +72,18 @@ class TestTunisia(CommonCountryTests, TestCase):
             ("2023-01-14", "عيد الثورة والشباب"),
             ("2023-03-20", "عيد الإستقلال"),
             ("2023-04-09", "عيد الشهداء"),
-            ("2023-04-21", "(تقدير) عيد الفطر"),
-            ("2023-04-22", "(تقدير) عطلة عيد الفطر"),
-            ("2023-04-23", "(تقدير) عطلة عيد الفطر"),
+            ("2023-04-21", "عيد الفطر (المقدرة)"),
+            ("2023-04-22", "عطلة عيد الفطر (المقدرة)"),
+            ("2023-04-23", "عطلة عيد الفطر (المقدرة)"),
             ("2023-05-01", "عيد العمال"),
-            ("2023-06-27", "(تقدير) يوم عرفة"),
-            ("2023-06-28", "(تقدير) عيد الأضحى"),
-            ("2023-06-29", "(تقدير) عطلة عيد الأضحى"),
-            ("2023-06-30", "(تقدير) عطلة عيد الأضحى"),
-            ("2023-07-19", "(تقدير) رأس السنة الهجرية"),
+            ("2023-06-27", "يوم عرفة (المقدرة)"),
+            ("2023-06-28", "عيد الأضحى (المقدرة)"),
+            ("2023-06-29", "عطلة عيد الأضحى (المقدرة)"),
+            ("2023-06-30", "عطلة عيد الأضحى (المقدرة)"),
+            ("2023-07-19", "رأس السنة الهجرية (المقدرة)"),
             ("2023-07-25", "عيد الجمهورية"),
             ("2023-08-13", "عيد المرأة"),
-            ("2023-09-27", "(تقدير) عيد المولد النبوي"),
+            ("2023-09-27", "عيد المولد النبوي (المقدرة)"),
             ("2023-10-15", "عيد الجلاء"),
         )
 
